==> haskell-keys-3.11-8-armv7h.pkg.tar.xz: usr/share/haskell/haskell-keys/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: keys
version: 3.11
id: keys-3.11-138176c47b9b6dd0d393596bbcd2f16d
key: keys_KQY4bQGDmrS1PTYlRp6s52
license: BSD3
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/keys/
synopsis: Keyed functors and containers
description:
    Keyed functors and containers
category: Data Structures, Containers
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Key
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/keys-3.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/keys-3.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/keys-3.11
hs-libraries: HSkeys-3.11-KQY4bQGDmrS1PTYlRp6s52
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-a91321d086a2de4a04a44d60c347669e
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    free-4.12.4-d9a4c0f5afbed93cf1b5cb75cd23ad91
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
haddock-interfaces: /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html: /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-keys-3.11-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-keys/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: keys
version: 3.11
id: keys-3.11-c0312e613ec912c390e00fde3001f005
key: keys_FT0yMgPq2OK0SRzfYlHeEH
license: BSD3
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/keys/
synopsis: Keyed functors and containers
description:
    Keyed functors and containers
category: Data Structures, Containers
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Key
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/keys-3.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/keys-3.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/keys-3.11
hs-libraries: HSkeys-3.11-FT0yMgPq2OK0SRzfYlHeEH
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-e98e7adc8875accf64a86529d9aeae51
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    free-4.12.4-a5ffddbbf41dcb5e4b11e5d62a21f456
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
haddock-interfaces: /usr/share/doc/haskell-keys/html/keys.haddock
haddock-html: /usr/share/doc/haskell-keys/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
